Text Models
===============
.. image:: https://travis-ci.org/INGEOTEC/text_models.svg?branch=master
	  :target: https://travis-ci.org/INGEOTEC/text_models

.. image:: https://badge.fury.io/py/text-models.svg
	  :target: https://badge.fury.io/py/text-models

.. image:: https://coveralls.io/repos/github/INGEOTEC/text_models/badge.svg?branch=master
	  :target: https://coveralls.io/github/INGEOTEC/text_models?branch=master

.. image:: https://readthedocs.org/projects/text-models/badge/?version=latest
      :target: https://text-models.readthedocs.io/en/latest/?badge=latest
      :alt: Documentation Status		    		       


INGEOTEC Text Model package deals with the creation of labeled
datasets using a self-supervised approach. It includes different text
models developed for Arabic, English, Spanish languages, as well as
the classes used to create them. Finally, it a modified Beam selection
technique, tailored to text classification, that chooses those text
models that are more suitable for a given text classification problem.

The documentation is on `readthedocs <https://text_models.readthedocs.io>`_.
